import { Database } from "sql.js";
export declare enum WasmSources {
    prod = "https://cdnjs.cloudflare.com/ajax/libs/sql.js/1.6.1/sql-wasm.wasm",
    debug = "https://cdnjs.cloudflare.com/ajax/libs/sql.js/1.6.1/sql-wasm-debug.wasm",
    test = "node_modules/sql.js/dist/sql-wasm.wasm"
}
/**
 * Defines the Singleton holding the database instance.
 */
export interface DatabaseHolder {
    instance: Database | null;
    setInstance: (bd: Database) => void;
    getInstance: () => Database | null;
    destroy: () => void;
}
export declare type SqlDataType = 'INTEGER' | 'INT' | 'TEXT' | 'DATE';
/**
 * Structure that defines the schema definition of a table
 */
export declare type TableDefinitions = {
    fields: Record<string, SqlDataType>;
    values?: Array<Record<string, string | number>>;
};
/**
 * Structure that defines the database schema.
 * Each key of the 'Record' refers to a table name, and the TableDefinitions
 * defines the initial construction of the table.
 */
export declare type Schema = Record<string, TableDefinitions>;
/**
 * Defines the Recorder type.
 * Each string in the Record is associated with a table.
 * Each weakRef item is connected to a 'reactive' function that must be fired
 * after an insert query.
 */
export declare type Recorder = Record<string, Array<WeakRef<(t: number) => void>>>;
