import * as sql_js from 'sql.js';
import { Database } from 'sql.js';

declare type SqlDataType = 'INTEGER' | 'INT' | 'TEXT' | 'DATE';
/**
 * Structure that defines the schema definition of a table
 */
declare type TableDefinitions = {
    fields: Record<string, SqlDataType>;
    values?: Array<Record<string, string | number>>;
};
/**
 * Structure that defines the database schema.
 * Each key of the 'Record' refers to a table name, and the TableDefinitions
 * defines the initial construction of the table.
 */
declare type Schema = Record<string, TableDefinitions>;

/**
 * Public interface to destroy the database.
 * It executes the db.close() function, and remove it from the singleton holder.
 */
declare const destroyDatabase: () => void;
/**
 * Create SQLite instance using sql.js, from the input 'path' to the wasm file,
 * and schema definition.
 *
 *
 * @param path      Path to the wasm file
 * @param schema    Schema definition to create the database
 * @return database or undefined
 */
declare const createSQL: (path: string, schema: Schema) => Promise<Database | undefined>;

declare function useQuery(query: string, depths?: Array<string | number | boolean | undefined | null>): {
    result: sql_js.QueryExecResult[] | undefined;
    writeQueryFn: (query: string) => void;
};

/**
 * Hook that provide write-only access to the database
 *
 */
declare function useInsert(): (query: string) => void;

/**
 * Hook that provide read-only access to the database
 *
 * @param query     Query to be executed
 * @param depths
 */
declare function useSelect(query: string, depths?: Array<string | number | boolean | undefined | null>): sql_js.QueryExecResult[] | undefined;

export { createSQL as default, destroyDatabase, useInsert, useQuery, useSelect };
